@@ -1,5 +1,6 @@
 # btssoap.rb - ruby interface for Debian BTS SOAP engine
-# Copyright (c) 2006-2007 Junichi Uekawa
+# Copyright (c) 2006-2008 Junichi Uekawa <dancer@debian.org>
+# Copyright (c) 2009      Francesco Poli <frx@firenze.linux.it>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -55,14 +56,16 @@ module Debian
           puts "No bugs to fetch" if $DEBUG
         else
           puts "fetching #{sa.join(" ")}.. " if $DEBUG
+          # get the SOAP driver to send 'get_status'
           @drv.get_status(sa).each { |bugnum, res|
+            # parse the received information, given from the server
             p res if $DEBUG
             res.package.split(/[ \t?,()]+/).each { |package|
               newbug=Debian::Bug.new(package, 
                                      bugnum.to_s, 
                                      res.severity,
                                      res.pending, 
-                                     res.subject,
+                                     res.subject.gsub(/\r/,''),
                                      res.tags.split(" "),
                                      res.mergedwith.to_s.split(" "),
                                      Time::at(res.date.to_i))
